@@ -1,9 +1,9 @@
 /*
  * PgBouncer - Lightweight connection pooler for PostgreSQL.
  * 
- * Copyright (c) 2007 Marko Kreen, Skype Technologies OÜ
+ * Copyright (c) 2007-2009  Marko Kreen, Skype Technologies OÜ
  * 
- * Permission to use, copy, modify, and distribute this software for any
+ * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
  * 
@@ -39,8 +39,6 @@
  *	send_pending();
  */	
 
-extern int cf_sbuf_len;
-
 /*
  * 0 .. done_pos         -- sent
  * done_pos .. parse_pos -- parsed, to send
@@ -86,22 +84,22 @@ static inline unsigned iobuf_amount_recv(const IOBuf *buf)
 }
 
 /* put all unparsed to mbuf */
-static inline unsigned iobuf_parse_all(const IOBuf *buf, MBuf *mbuf)
+static inline unsigned iobuf_parse_all(const IOBuf *buf, struct MBuf *mbuf)
 {
 	unsigned avail = iobuf_amount_parse(buf);
 	const uint8_t *pos = buf->buf + buf->parse_pos;
-	mbuf_init(mbuf, pos, avail);
+	mbuf_init_fixed_reader(mbuf, pos, avail);
 	return avail;
 }
 
 /* put all unparsed to mbuf, with size limit */
-static inline unsigned iobuf_parse_limit(const IOBuf *buf, MBuf *mbuf, unsigned limit)
+static inline unsigned iobuf_parse_limit(const IOBuf *buf, struct MBuf *mbuf, unsigned limit)
 {
 	unsigned avail = iobuf_amount_parse(buf);
 	const uint8_t *pos = buf->buf + buf->parse_pos;
 	if (avail > limit)
 		avail = limit;
-	mbuf_init(mbuf, pos, avail);
+	mbuf_init_fixed_reader(mbuf, pos, avail);
 	return avail;
 }
 
