@@ -1,9 +1,9 @@
 /*
  * PgBouncer - Lightweight connection pooler for PostgreSQL.
  * 
- * Copyright (c) 2007 Marko Kreen, Skype Technologies OÜ
+ * Copyright (c) 2007-2009  Marko Kreen, Skype Technologies OÜ
  * 
- * Permission to use, copy, modify, and distribute this software for any
+ * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
  * 
@@ -18,6 +18,6 @@
 
 void stats_setup(void);
 
-bool admin_database_stats(PgSocket *client, StatList *pool_list)  _MUSTCHECK;
-bool show_stat_totals(PgSocket *client, StatList *pool_list)  _MUSTCHECK;
+bool admin_database_stats(PgSocket *client, struct StatList *pool_list)  _MUSTCHECK;
+bool show_stat_totals(PgSocket *client, struct StatList *pool_list)  _MUSTCHECK;
 
