@@ -43,6 +43,7 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <unistd.h>
+#include <assert.h>
 
 #ifdef WIN32
 #include <usual/base_win32.h>
@@ -90,10 +91,34 @@
 #define FLEX_ARRAY 1
 #endif
 
+/** Make string token from C expression */
+#define STR(x) _STR_(x)
+#define _STR_(x) #x
+
+/** Make single C token from 2 separate tokens */
+#define CONCAT(a, b)    _CONCAT_(a, b)
+#define _CONCAT_(a, b)  a ## b
+
+/** Make single C token from 3 separate tokens */
+#define CONCAT3(a, b, c)     _CONCAT3_(a, b, c)
+#define _CONCAT3_(a, b, c)  a ## b ## c
+
+/** Make single C token from 4 separate tokens */
+#define CONCAT4(a, b, c, d)    _CONCAT4_(a, b, c, d)
+#define _CONCAT4_(a, b, c, d)  a ## b ## c ## d
+
 /**
  * @name Compiler attributes.
  */
 
+/* Compiler detection for internal usage.  */
+#define _COMPILER_GNUC(maj,min) (defined(__GNUC__) && \
+	  ((__GNUC__ > (maj)) || (__GNUC__ == (maj) && __GNUC_MINOR__ >= (min))))
+#define _COMPILER_CLANG(maj,min) (defined(__clang__) && \
+	   ((__clang_major__ > (maj)) || (__clang_major__ == (maj) && __clang_minor__ >= (min))))
+#define _COMPILER_MSC(ver) (defined(_MSC_VER) && (_MSC_VER >= (ver)))
+#define _COMPILER_ICC(ver) (defined(__INTEL_COMPILER) && (__INTEL_COMPILER >= (ver)))
+
 /** Disable padding for structure */
 #define _PACKED			__attribute__((packed))
 
@@ -147,6 +172,26 @@
 
 /* @} */
 
+
+/**
+ * Compile-time assert.
+ *
+ * Expression must be evaluatable at compile time.
+ * If false, stop compilation with message.
+ *
+ * It can be used in either global or function scope.
+ */
+#ifndef static_assert
+#if _COMPILER_GNUC(4,6) || _COMPILER_CLANG(3,0) || _COMPILER_MSC(1600)
+/* Version for new compilers */
+#define static_assert(expr, msg) _Static_assert(expr, msg)
+#else
+/* Version for old compilers */
+#define static_assert(expr, msg) enum { CONCAT4(static_assert_failure_, __LINE__, _, __COUNTER__) = 1/(1 != (1 + (expr))) }
+#endif
+#endif /* !static_assert */
+
+
 /** assert() that uses <usual/logging> module  */
 #ifndef Assert
 #ifdef CASSERT
@@ -185,9 +230,5 @@ static inline void *zmalloc(size_t len)
 int posix_memalign(void **ptr_p, size_t align, size_t len);
 #endif
 
-/** cpp expr -> string */
-#define STR(x) _STR_(x)
-#define _STR_(x) #x
-
 #endif
 
