@@ -430,6 +430,18 @@ static void check_pool_size(PgPool *pool)
 			break;
 		disconnect_server(server, true, "too many servers in the pool");
 		many--;
+		cur--;
+	}
+
+	/* launch extra connections to satisfy min_pool_size */
+	if (cur < cf_min_pool_size &&
+	    cur < pool->db->pool_size &&
+	    cf_pause_mode == P_NONE &&
+	    cf_reboot == 0 &&
+	    pool_client_count(pool) > 0)
+	{
+		log_debug("Launching new connection to satisfy min_pool_size");
+		launch_new_connection(pool);
 	}
 }
 
@@ -446,15 +458,21 @@ static void pool_server_maint(PgPool *pool)
 	check_unused_servers(pool, &pool->idle_server_list, 1);
 
 	/* where query got did not get answer in query_timeout */
-	if (cf_query_timeout > 0) {
+	if (cf_query_timeout > 0 || cf_idle_transaction_timeout > 0) {
 		statlist_for_each_safe(item, &pool->active_server_list, tmp) {
 			server = container_of(item, PgSocket, head);
 			Assert(server->state == SV_ACTIVE);
 			if (server->ready)
 				continue;
 			age = now - server->link->request_time;
-			if (age > cf_query_timeout)
+			if (cf_query_timeout > 0 && age > cf_query_timeout) {
 				disconnect_server(server, true, "query timeout");
+			} else if (cf_idle_transaction_timeout > 0 &&
+				   server->idle_tx &&
+				   age > cf_idle_transaction_timeout)
+			{
+				disconnect_server(server, true, "idle transaction timeout");
+			}
 		}
 	}
 
@@ -505,6 +523,8 @@ static void cleanup_inactive_autodatabases(void)
 	/* now kill the old ones */
 	statlist_for_each_safe(item, &autodatabase_idle_list, tmp) {
 		db = container_of(item, PgDatabase, head);
+		if (db->db_paused)
+			continue;
 		age = now - db->inactive_time;
 		if (age > cf_autodb_idle_timeout) 
 			kill_database(db);
@@ -569,6 +589,8 @@ static void do_full_maint(int sock, short flags, void *arg)
 	if (cf_auth_type >= AUTH_TRUST)
 		loader_users_check();
 
+	adns_zone_cache_maint(adns);
+
 skip_maint:
 	safe_evtimer_add(&full_maint_ev, &full_maint_period);
 }
@@ -581,7 +603,7 @@ void janitor_setup(void)
 	safe_evtimer_add(&full_maint_ev, &full_maint_period);
 }
 
-static void kill_pool(PgPool *pool)
+void kill_pool(PgPool *pool)
 {
 	const char *reason = "database removed";
 
