@@ -1,9 +1,9 @@
 /*
  * PgBouncer - Lightweight connection pooler for PostgreSQL.
  * 
- * Copyright (c) 2007 Marko Kreen, Skype Technologies OÜ
+ * Copyright (c) 2007-2009  Marko Kreen, Skype Technologies OÜ
  * 
- * Permission to use, copy, modify, and distribute this software for any
+ * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
  * 
@@ -75,7 +75,7 @@ static void takeover_finish_part1(PgSocket *bouncer)
 }
 
 /* parse msg for fd and info */
-static void takeover_load_fd(MBuf *pkt, const struct cmsghdr *cmsg)
+static void takeover_load_fd(struct MBuf *pkt, const struct cmsghdr *cmsg)
 {
 	int fd;
 	char *task, *saddr, *user, *db;
@@ -102,7 +102,7 @@ static void takeover_load_fd(MBuf *pkt, const struct cmsghdr *cmsg)
 	got = scan_text_result(pkt, "issssiqissss", &oldfd, &task, &user, &db,
 			       &saddr, &port, &ckey, &linkfd,
 			       &client_enc, &std_string, &datestyle, &timezone);
-	if (task == NULL || saddr == NULL)
+	if (got < 0 || task == NULL || saddr == NULL)
 		fatal("NULL data from old process");
 
 	log_debug("FD row: fd=%d(%d) linkfd=%d task=%s user=%s db=%s enc=%s",
@@ -111,12 +111,11 @@ static void takeover_load_fd(MBuf *pkt, const struct cmsghdr *cmsg)
 		  client_enc ? client_enc : "NULL");
 
 	/* fill address */
-	addr.is_unix = strcmp(saddr, "unix") == 0 ? true : false;
-	if (addr.is_unix) {
-		addr.port = cf_listen_port;
+	if (strcmp(saddr, "unix") == 0) {
+		pga_set(&addr, AF_UNIX, cf_listen_port);
 	} else {
-		addr.ip_addr.s_addr = inet_addr(saddr);
-		addr.port = port;
+		if (!pga_pton(&addr, saddr, port))
+			fatal("failed to convert address: %s", saddr);
 	}
 
 	/* decide what to do with it */
@@ -127,7 +126,7 @@ static void takeover_load_fd(MBuf *pkt, const struct cmsghdr *cmsg)
 		res = use_server_socket(fd, &addr, db, user, ckey, oldfd, linkfd,
 				  client_enc, std_string, datestyle, timezone);
 	else if (strcmp(task, "pooler") == 0)
-		res = use_pooler_socket(fd, addr.is_unix);
+		res = use_pooler_socket(fd, pga_is_unix(&addr));
 	else
 		fatal("unknown task: %s", task);
 
@@ -137,7 +136,7 @@ static void takeover_load_fd(MBuf *pkt, const struct cmsghdr *cmsg)
 
 static void takeover_create_link(PgPool *pool, PgSocket *client)
 {
-	List *item;
+	struct List *item;
 	PgSocket *server;
 
 	statlist_for_each(item, &pool->active_server_list) {
@@ -152,9 +151,9 @@ static void takeover_create_link(PgPool *pool, PgSocket *client)
 }
 
 /* clean the inappropriate places the old fds got stored in */
-static void takeover_clean_socket_list(StatList *list)
+static void takeover_clean_socket_list(struct StatList *list)
 {
-	List *item;
+	struct List *item;
 	PgSocket *sk;
 	statlist_for_each(item, list) {
 		sk = container_of(item, PgSocket, head);
@@ -168,7 +167,7 @@ static void takeover_clean_socket_list(StatList *list)
 /* all fds loaded, create links */
 static void takeover_postprocess_fds(void)
 {
-	List *item, *item2;
+	struct List *item, *item2;
 	PgSocket *client;
 	PgPool *pool;
 
@@ -190,10 +189,13 @@ static void takeover_postprocess_fds(void)
 	}
 }
 
-static void next_command(PgSocket *bouncer, MBuf *pkt)
+static void next_command(PgSocket *bouncer, struct MBuf *pkt)
 {
 	bool res = true;
-	const char *cmd = mbuf_get_string(pkt);
+	const char *cmd;
+	
+	if (!mbuf_get_string(pkt, &cmd))
+		fatal("bad result pkt");
 
 	log_debug("takeover_recv_fds: 'C' body: %s", cmd);
 	if (strcmp(cmd, "SUSPEND") == 0) {
@@ -213,14 +215,14 @@ static void next_command(PgSocket *bouncer, MBuf *pkt)
 }
 
 static void takeover_parse_data(PgSocket *bouncer,
-				struct msghdr *msg, MBuf *data)
+				struct msghdr *msg, struct MBuf *data)
 {
 	struct cmsghdr *cmsg;
 	PktHdr pkt;
 	
 	cmsg = msg->msg_controllen ? CMSG_FIRSTHDR(msg) : NULL;
 
-	while (mbuf_avail(data) > 0) {
+	while (mbuf_avail_for_read(data) > 0) {
 		if (!get_header(data, &pkt))
 			fatal("cannot parse packet");
 
@@ -266,12 +268,12 @@ static void takeover_parse_data(PgSocket *bouncer,
 static void takeover_recv_cb(int sock, short flags, void *arg)
 {
 	PgSocket *bouncer = container_of(arg, PgSocket, sbuf);
-	uint8_t data_buf[2048];
+	uint8_t data_buf[STARTUP_BUF * 2];
 	uint8_t cnt_buf[128];
 	struct msghdr msg;
 	struct iovec io;
 	int res;
-	MBuf data;
+	struct MBuf data;
 
 	memset(&msg, 0, sizeof(msg));
 	io.iov_base = data_buf;
@@ -283,7 +285,7 @@ static void takeover_recv_cb(int sock, short flags, void *arg)
 
 	res = safe_recvmsg(sock, &msg, 0);
 	if (res > 0) {
-		mbuf_init(&data, data_buf, res);
+		mbuf_init_fixed_reader(&data, data_buf, res);
 		takeover_parse_data(bouncer, &msg, &data);
 	} else if (res == 0) {
 		fatal("unexpected EOF");
